// Copyright 2017 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

syntax = "proto3";

package google.crypto.tink;

import "proto/tink.proto";

option java_package = "com.google.crypto.tink.proto";
option java_multiple_files = true;
option go_package = "github.com/google/tink/go/proto/kms_envelope_go_proto";

message KmsEnvelopeAeadKeyFormat {
  // Required.
  // The location of the KEK in a remote KMS.
  // With Google Cloud KMS, valid values have this format:
  // gcp-kms://projects/*/locations/*/keyRings/*/cryptoKeys/*.
  // With AWS KMS, valid values have this format:
  // aws-kms://arn:aws:kms:<region>:<account-id>:key/<key-id>
  string kek_uri = 1;
  // Key template of the Data Encryption Key, e.g., AesCtrHmacAeadKeyFormat.
  // Required.
  KeyTemplate dek_template = 2;
}

// There is no actual key material in the key.
message KmsEnvelopeAeadKey {
  uint32 version = 1;
  // The key format also contains the params.
  KmsEnvelopeAeadKeyFormat params = 2;
}
